@@ -225,34 +225,75 @@ class CimisClient:
                        end_date: Union[str, date, datetime],
                        data_items: Optional[List[str]] = None,
                        unit_of_measure: str = 'E',
-                       prioritize_scs: bool = True) -> WeatherData:
+                       prioritize_scs: bool = True,
+                       csv: bool = False,
+                       filename: Optional[Union[str, Path]] = None) -> Union[WeatherData, tuple[WeatherData, str]]:
         """
         Get daily weather data from CIMIS.
         
         This is a convenience method that uses default daily data items.
+        
+        Args:
+            targets: Station numbers, zip codes, coordinates, or addresses
+            start_date: Start date for data retrieval
+            end_date: End date for data retrieval
+            data_items: List of data items to retrieve (uses default if None)
+            unit_of_measure: 'E' for English or 'M' for Metric
+            prioritize_scs: Whether to prioritize SCS data for zip codes
+            csv: If True, automatically export to CSV with auto-generated filename
+            filename: Custom filename for CSV export (only used if csv=True)
+            
+        Returns:
+            WeatherData object if csv=False, or tuple of (WeatherData, csv_filename) if csv=True
         """
         if data_items is None:
             data_items = []  # Empty list will get all available data items
         
-        return self.get_data(targets, start_date, end_date, data_items, 
-                           unit_of_measure, prioritize_scs)
+        weather_data = self.get_data(targets, start_date, end_date, data_items, 
+                                   unit_of_measure, prioritize_scs)
+        
+        if csv:
+            csv_filename = self.export_to_csv(weather_data, filename)
+            return weather_data, csv_filename
+        
+        return weather_data
     
     def get_hourly_data(self, 
                         targets: Union[str, List[str]], 
                         start_date: Union[str, date, datetime],
                         end_date: Union[str, date, datetime],
                         data_items: Optional[List[str]] = None,
-                        unit_of_measure: str = 'E') -> WeatherData:
+                        unit_of_measure: str = 'E',
+                        csv: bool = False,
+                        filename: Optional[Union[str, Path]] = None) -> Union[WeatherData, tuple[WeatherData, str]]:
         """
         Get hourly weather data from CIMIS.
         
         Note: Hourly data is only available from WSN stations, not SCS.
+        
+        Args:
+            targets: Station numbers, zip codes, coordinates, or addresses
+            start_date: Start date for data retrieval
+            end_date: End date for data retrieval
+            data_items: List of data items to retrieve (uses default if None)
+            unit_of_measure: 'E' for English or 'M' for Metric
+            csv: If True, automatically export to CSV with auto-generated filename
+            filename: Custom filename for CSV export (only used if csv=True)
+            
+        Returns:
+            WeatherData object if csv=False, or tuple of (WeatherData, csv_filename) if csv=True
         """
         if data_items is None:
             data_items = []  # Empty list will get all available data items
         
-        return self.get_data(targets, start_date, end_date, data_items, 
-                           unit_of_measure, prioritize_scs=False)
+        weather_data = self.get_data(targets, start_date, end_date, data_items, 
+                                   unit_of_measure, prioritize_scs=False)
+        
+        if csv:
+            csv_filename = self.export_to_csv(weather_data, filename)
+            return weather_data, csv_filename
+        
+        return weather_data
     
     def get_stations(self, station_number: Optional[str] = None) -> List[Station]:
         """
