@@ -647,5 +647,181 @@ class TestClientErrorHandling:
             self.client._make_request("data", {})
 
 
+class TestClientCSVParameterSupport:
+    """Test CSV parameter support in get_daily_data and get_hourly_data methods."""
+    
+    def setup_method(self):
+        """Set up test client."""
+        self.client = CimisClient(app_key="test-api-key")
+    
+    @patch('python_cimis.client.CimisClient.get_data')
+    @patch('python_cimis.client.CimisClient.export_to_csv')
+    def test_get_daily_data_with_csv_true(self, mock_export, mock_get_data):
+        """Test get_daily_data with csv=True parameter."""
+        # Mock the get_data response
+        mock_weather_data = Mock()
+        mock_get_data.return_value = mock_weather_data
+        
+        # Mock the CSV export
+        mock_export.return_value = "auto_generated_daily.csv"
+        
+        # Call with csv=True
+        result = self.client.get_daily_data(
+            targets=[2],
+            start_date="2023-01-01",
+            end_date="2023-01-02",
+            csv=True
+        )
+        
+        # Should return tuple of (weather_data, csv_filename)
+        assert isinstance(result, tuple)
+        assert len(result) == 2
+        weather_data, csv_filename = result
+        assert weather_data == mock_weather_data
+        assert csv_filename == "auto_generated_daily.csv"
+        
+        # Verify methods were called correctly
+        mock_get_data.assert_called_once_with(
+            [2], "2023-01-01", "2023-01-02", [], 'E', True
+        )
+        mock_export.assert_called_once_with(mock_weather_data, None)
+    
+    @patch('python_cimis.client.CimisClient.get_data')
+    @patch('python_cimis.client.CimisClient.export_to_csv')
+    def test_get_daily_data_with_csv_false(self, mock_export, mock_get_data):
+        """Test get_daily_data with csv=False (default)."""
+        # Mock the get_data response
+        mock_weather_data = Mock()
+        mock_get_data.return_value = mock_weather_data
+        
+        # Call with csv=False (default)
+        result = self.client.get_daily_data(
+            targets=[2],
+            start_date="2023-01-01",
+            end_date="2023-01-02"
+        )
+        
+        # Should return just the weather_data object
+        assert result == mock_weather_data
+        
+        # Verify get_data was called but export_to_csv was not
+        mock_get_data.assert_called_once()
+        mock_export.assert_not_called()
+    
+    @patch('python_cimis.client.CimisClient.get_data')
+    @patch('python_cimis.client.CimisClient.export_to_csv')
+    def test_get_daily_data_with_custom_filename(self, mock_export, mock_get_data):
+        """Test get_daily_data with csv=True and custom filename."""
+        # Mock the get_data response
+        mock_weather_data = Mock()
+        mock_get_data.return_value = mock_weather_data
+        
+        # Mock the CSV export
+        mock_export.return_value = "custom_daily.csv"
+        
+        # Call with csv=True and custom filename
+        result = self.client.get_daily_data(
+            targets=[2],
+            start_date="2023-01-01",
+            end_date="2023-01-02",
+            csv=True,
+            filename="custom_daily.csv"
+        )
+        
+        # Should return tuple with custom filename
+        weather_data, csv_filename = result
+        assert csv_filename == "custom_daily.csv"
+        
+        # Verify export was called with custom filename
+        mock_export.assert_called_once_with(mock_weather_data, "custom_daily.csv")
+    
+    @patch('python_cimis.client.CimisClient.get_data')
+    @patch('python_cimis.client.CimisClient.export_to_csv')
+    def test_get_hourly_data_with_csv_true(self, mock_export, mock_get_data):
+        """Test get_hourly_data with csv=True parameter."""
+        # Mock the get_data response
+        mock_weather_data = Mock()
+        mock_get_data.return_value = mock_weather_data
+        
+        # Mock the CSV export
+        mock_export.return_value = "auto_generated_hourly.csv"
+        
+        # Call with csv=True
+        result = self.client.get_hourly_data(
+            targets=[2],
+            start_date="2023-01-01",
+            end_date="2023-01-01",  # Shorter period for hourly
+            csv=True
+        )
+        
+        # Should return tuple of (weather_data, csv_filename)
+        assert isinstance(result, tuple)
+        assert len(result) == 2
+        weather_data, csv_filename = result
+        assert weather_data == mock_weather_data
+        assert csv_filename == "auto_generated_hourly.csv"
+        
+        # Verify methods were called correctly (prioritize_scs=False for hourly)
+        mock_get_data.assert_called_once_with(
+            [2], "2023-01-01", "2023-01-01", [], 'E', prioritize_scs=False
+        )
+        mock_export.assert_called_once_with(mock_weather_data, None)
+    
+    @patch('python_cimis.client.CimisClient.get_data')
+    @patch('python_cimis.client.CimisClient.export_to_csv')
+    def test_get_hourly_data_with_csv_false(self, mock_export, mock_get_data):
+        """Test get_hourly_data with csv=False (default)."""
+        # Mock the get_data response
+        mock_weather_data = Mock()
+        mock_get_data.return_value = mock_weather_data
+        
+        # Call with csv=False (default)
+        result = self.client.get_hourly_data(
+            targets=[2],
+            start_date="2023-01-01",
+            end_date="2023-01-01"
+        )
+        
+        # Should return just the weather_data object
+        assert result == mock_weather_data
+        
+        # Verify get_data was called but export_to_csv was not
+        mock_get_data.assert_called_once()
+        mock_export.assert_not_called()
+    
+    @patch('python_cimis.client.CimisClient.get_data')
+    @patch('python_cimis.client.CimisClient.export_to_csv')
+    def test_get_hourly_data_with_all_parameters(self, mock_export, mock_get_data):
+        """Test get_hourly_data with all parameters including csv=True."""
+        # Mock the get_data response
+        mock_weather_data = Mock()
+        mock_get_data.return_value = mock_weather_data
+        
+        # Mock the CSV export
+        mock_export.return_value = "hourly_detailed.csv"
+        
+        # Call with all parameters
+        result = self.client.get_hourly_data(
+            targets=[2, 6],
+            start_date="2023-01-01",
+            end_date="2023-01-01",
+            data_items=["hly-air-tmp", "hly-rel-hum"],
+            unit_of_measure="M",
+            csv=True,
+            filename="hourly_detailed.csv"
+        )
+        
+        # Should return tuple
+        weather_data, csv_filename = result
+        assert csv_filename == "hourly_detailed.csv"
+        
+        # Verify all parameters were passed correctly
+        mock_get_data.assert_called_once_with(
+            [2, 6], "2023-01-01", "2023-01-01", 
+            ["hly-air-tmp", "hly-rel-hum"], 'M', prioritize_scs=False
+        )
+        mock_export.assert_called_once_with(mock_weather_data, "hourly_detailed.csv")
+
+
 if __name__ == "__main__":
     pytest.main([__file__])
